@@ -56,21 +56,13 @@ deletecache() {
 			fi
 			;;
 		esac
-		case "$dist" in
-			oldstable)
-				if [ -e "$dir/debian-security/dists/$dist/updates" ]; then
-					rm --one-file-system --recursive "$dir/debian-security/dists/$dist/updates"
-				else
-					echo "does not exist: $dir/debian-security/dists/$dist/updates" >&2
-				fi
-				;;
-			stable)
-				if [ -e "$dir/debian-security/dists/$dist-security" ]; then
-					rm --one-file-system --recursive "$dir/debian-security/dists/$dist-security"
-				else
-					echo "does not exist: $dir/debian-security/dists/$dist-security" >&2
-				fi
-				;;
+		case "$dist" in oldstable|stable)
+			if [ -e "$dir/debian-security/dists/$dist-security" ]; then
+				rm --one-file-system --recursive "$dir/debian-security/dists/$dist-security"
+			else
+				echo "does not exist: $dir/debian-security/dists/$dist-security" >&2
+			fi
+			;;
 		esac
 	done
 	for f in "$dir/debian-"*.qcow; do
@@ -112,7 +104,6 @@ deletecache() {
 }
 
 cleanup_newcachedir() {
-	kill "$PROXYPID" || :
 	echo "running cleanup_newcachedir"
 	deletecache "$newcachedir"
 }
@@ -163,7 +154,7 @@ update_cache() (
 	# we only set this trap here and overwrite the previous trap, because
 	# the update_cache function is run as part of a pipe and thus in its
 	# own process which will EXIT after it finished
-	trap "cleanupapt" EXIT INT TERM
+	trap 'kill "$PROXYPID" || :;cleanupapt' EXIT INT TERM
 
 	for p in /etc/apt/apt.conf.d /etc/apt/sources.list.d /etc/apt/preferences.d /var/cache/apt/archives /var/lib/apt/lists/partial /var/lib/dpkg; do
 		mkdir -p "$rootdir/$p"
@@ -225,7 +216,7 @@ END
 		cat "$rootdir/$f" >&2
 	done
 
-	APT_CONFIG="$rootdir/etc/apt/apt.conf" apt-get update
+	APT_CONFIG="$rootdir/etc/apt/apt.conf" apt-get update --error-on=any
 
 	pkgs=$(APT_CONFIG="$rootdir/etc/apt/apt.conf" apt-get indextargets \
 		--format '$(FILENAME)' 'Created-By: Packages' "Architecture: $nativearch" \
@@ -240,7 +231,7 @@ END
 	# we need usr-is-merged to simulate debootstrap behaviour for all dists
 	# starting from Debian 12 (Bullseye)
 	case "$dist" in
-		oldstable|stable) : ;;
+		oldstable) : ;;
 		*) pkgs="$pkgs usr-is-merged usrmerge" ;;
 	esac
 
@@ -322,6 +313,7 @@ fi
 
 ./caching_proxy.py "$oldcachedir" "$newcachedir" &
 PROXYPID=$!
+trap 'kill "$PROXYPID" || :' EXIT INT TERM
 
 for i in $(seq 10); do
 	curl --proxy "http://127.0.0.1:8080/" --silent -o /dev/null "http://deb.debian.org/debian/dists/$DEFAULT_DIST/InRelease" && break
@@ -333,7 +325,7 @@ if [ ! -s "$newmirrordir/dists/$DEFAULT_DIST/InRelease" ]; then
 	exit 1
 fi
 
-trap "cleanup_newcachedir" EXIT INT TERM
+trap 'kill "$PROXYPID" || :;cleanup_newcachedir' EXIT INT TERM
 
 mkdir -p "$newcachedir"
 touch "$newcachedir/mmdebstrapcache"
@@ -369,16 +361,8 @@ for dist in oldstable stable testing unstable; do
 		echo "deb [arch=$nativearch] $mirror $dist $components" | update_cache "$dist" "$nativearch"
 		# we need to include the base mirror again or otherwise
 		# packages like build-essential will be missing
-		case "$dist" in
-			oldstable)
-				cat << END | update_cache "$dist" "$nativearch"
-deb [arch=$nativearch] $mirror $dist $components
-deb [arch=$nativearch] $mirror $dist-updates main
-deb [arch=$nativearch] $security_mirror $dist/updates main
-END
-				;;
-			stable)
-				cat << END | update_cache "$dist" "$nativearch"
+		case "$dist" in oldstable|stable)
+			cat << END | update_cache "$dist" "$nativearch"
 deb [arch=$nativearch] $mirror $dist $components
 deb [arch=$nativearch] $mirror $dist-updates main
 deb [arch=$nativearch] $security_mirror $dist-security main
@@ -471,12 +455,9 @@ if [ "$HAVE_QEMU" = "yes" ]; then
 	#   - it doesn't matter if the base system is from a different mirror timestamp
 	# procps is needed for /sbin/sysctl
 	tmpdir="$(mktemp -d)"
-	trap "cleanuptmpdir; cleanup_newcachedir" EXIT INT TERM
+	trap 'kill "$PROXYPID" || :;cleanuptmpdir; cleanup_newcachedir' EXIT INT TERM
 
-	pkgs=perl-doc,systemd-sysv,perl,arch-test,fakechroot,fakeroot,mount,uidmap,qemu-user-static,binfmt-support,qemu-user,dpkg-dev,mini-httpd,libdevel-cover-perl,libtemplate-perl,debootstrap,procps,apt-cudf,aspcud,python3,libcap2-bin,gpg,debootstrap,distro-info-data,iproute2,ubuntu-keyring,apt-utils,grub-efi
-	if [ "$DEFAULT_DIST" != "oldstable" ]; then
-		pkgs="$pkgs,squashfs-tools-ng,genext2fs"
-	fi
+	pkgs=perl-doc,systemd-sysv,perl,arch-test,fakechroot,fakeroot,mount,uidmap,qemu-user-static,binfmt-support,qemu-user,dpkg-dev,mini-httpd,libdevel-cover-perl,libtemplate-perl,debootstrap,procps,apt-cudf,aspcud,python3,libcap2-bin,gpg,debootstrap,distro-info-data,iproute2,ubuntu-keyring,apt-utils,grub-efi,disorderfs,squashfs-tools-ng,genext2fs
 	if [ ! -e ./mmdebstrap ]; then
 		pkgs="$pkgs,mmdebstrap"
 	fi
